Learn R Programming

RcmdrMisc (version 2.10.2)

Gumbel: The Gumbel Distribution

Description

The Gumbel Distribution

Usage

dgumbel(x, location = 0, scale = 1)

pgumbel(q, location = 0, scale = 1, lower.tail = TRUE)

qgumbel(p, location = 0, scale = 1, lower.tail = TRUE)

rgumbel(n, location = 0, scale = 1)

Arguments

x

vector of values of the variable.

location

location parameter (default 0); potentially a vector.

scale

scale parameter (default 1); potentially a vector.

q

vector of quantiles.

lower.tail

logical; if TRUE (the default) probabilities and quantiles correspond to \(P(X \le x)\), if FALSE to \(P(X > x)\).

p

vector of probabilities.

n

number of observations. If length(n) > 1, the length is taken to be the number required.

Author

John Fox

Details

Density, distribution function, quantile function and random generation for the Gumbel distribution with specified location and scale parameters.

References

See https://en.wikipedia.org/wiki/Gumbel_distribution for details of the Gumbel distribution.

Examples

Run this code
x <- 100 + 5*c(-Inf, -1, 0, 1, 2, 3, Inf, NA)
dgumbel(x, 100, 5)
pgumbel(x, 100, 5)
p <- c(0, .25, .5, .75, 1, NA)
qgumbel(p, 100, 5)
summary(rgumbel(1e5, 100, 5))

Run the code above in your browser using DataLab