For a numeric vector, invisibly returns the vector of counts, named with the end-points of the corresponding bins. For a matrix or data frame, invisibly returns NULL
Arguments
x
a numeric vector, matrix, or data frame.
breaks
specification of the breaks between bins, to be passed to the hist function.
round.percents
number of decimal places to round percentages; default is 2.
name
for the variable; only used for vector argument x.
Author
John Fox
Details
Bins a numeric variable, as for a histogram, and reports the count and percentage in each bin.
The computations are done by the hist function, but no histogram is drawn.
If supplied a numeric matrix or data frame, the distribution of each column is printed.