Learn R Programming

RcmdrMisc (version 1.0-2)

colPercents: Row, Column, and Total Percentage Tables

Description

Percentage a matrix or higher-dimensional array of frequency counts by rows, columns, or total frequency.

Usage

colPercents(tab, digits=1)
rowPercents(tab, digits=1)
totPercents(tab, digits=1)

Arguments

tab
a matrix or higher-dimensional array of frequency counts.
digits
number of places to the right of the decimal place for percentages.

Value

  • Returns an array of the same size and shape as tab percentaged by rows or columns, plus rows or columns of totals and counts, or by the table total.

Examples

Run this code
if (require(car)){
    data(Mroz) # from car package
    cat("column percents:
")
    print(colPercents(xtabs(~ lfp + wc, data=Mroz)))
    cat("row percents:
")
    print(rowPercents(xtabs(~ hc + lfp, data=Mroz)))
    cat("total percents:
")
    print(totPercents(xtabs(~ hc + wc, data=Mroz)))
    cat("three-way table, column percents:
")
    print(colPercents(xtabs(~ lfp + wc + hc, data=Mroz)))
}

Run the code above in your browser using DataLab