For a numeric vector, invisibly returns the table of counts. For a matrix or data frame, invisibly returns NULL
Arguments
x
a discrete numeric vector, matrix, or data frame.
round.percents
number of decimal places to round percentages; default is 2.
name
name for the variable; only used for vector argument x.
max.values
maximum number of unique values (default is the smallest of twice the square root of the number of elements in x, 10 times the log10 of the number of elements, and 100); if exceeded, an error is reported.
Author
John Fox
Details
Computes the frequency and percentage distribution of a descrete numeric variable or the distributions of the variables in a numeric matrix or data frame.