Learn R Programming

RcmdrMisc (version 2.10.2)

discretePlot: Plot Distribution of Discrete Numeric Variable

Description

Plot Distribution of Discrete Numeric Variable

Usage

discretePlot(
  x,
  by,
  scale = c("frequency", "percent"),
  xlab = deparse(substitute(x)),
  ylab = scale,
  main = "",
  xlim = NULL,
  ylim = NULL,
  ...
)

Value

Returns NULL invisibly.

Arguments

x

a numeric variable.

by

optionally a factor (or character or logical variable) by which to classify x.

scale

either "frequency" (the default) or "percent".

xlab

optional character string to label the horizontal axis.

ylab

optional character string to label the vertical axis.

main

optional main label for the plot (ignored if the by argument is specified).

xlim

two-element numeric vectors specifying the range of the x axes; if not specified, will be determined from the data.

ylim

two-element numeric vectors specifying the range of the y axes; if not specified, will be determined from the data; the lower limit of the y-axis should normally be 0 and a warning will be printed if it isn't.

...

other arguments to be passed to plot.

Author

John Fox

Details

Plot the distribution of a discrete numeric variable, optionally classified by a factor.

If the by argument is specified, then one plot is produced for each level of by; these are arranged vertically and all use the same scale for the horizontal and vertical axes.

See Also

Hist, Dotplot.

Examples

Run this code
data(mtcars)
mtcars$cyl <- factor(mtcars$cyl)
with(mtcars, discretePlot(carb))
with(mtcars, discretePlot(carb, scale="percent"))
with(mtcars, discretePlot(carb, by=cyl))

Run the code above in your browser using DataLab