Returns labelled indices of identified points or (invisibly) NULL if no points are identified or if there are multiple variables with some missing data.
Arguments
x
a numeric variable, a matrix whose columns are numeric variables, or a numeric data frame; if x is a matrix or data frame, plots vertically aligned index plots for the columns.
groups
an optional grouping variable, typically a factor (or character or logical variable).
labels
point labels; if x is a data frame, defaults to the row names of x, otherwise to the case index.