Learn R Programming

RcmdrMisc (version 2.10.2)

lineplot: Plot a one or more lines

Description

Plot a one or more lines

Usage

lineplot(x, ..., legend)

Value

Produces a plot; returns NULL invisibly.

Arguments

x

variable giving horizontal coordinates.

...

one or more variables giving vertical coordinates.

legend

plot legend? Default is TRUE if there is more than one variable to plot and FALSE is there is just one.

Author

John Fox

Details

This function plots lines for one or more variables against another variable, typically time series against time.

Examples

Run this code
data(Bfox)
Bfox$time <- as.numeric(rownames(Bfox))
with(Bfox, lineplot(time, menwage, womwage))

Run the code above in your browser using DataLab