Learn R Programming

RcmdrMisc (version 2.10.2)

mergeRows: Function to Merge Rows of Two Data Frames

Description

Function to Merge Rows of Two Data Frames

Usage

mergeRows(X, Y, common.only = FALSE, ...)

# S3 method for data.frame mergeRows(X, Y, common.only = FALSE, ...)

Value

A data frame containing the rows from both input data frames.

Arguments

X

First data frame.

Y

Second data frame.

common.only

If TRUE, only variables (columns) common to the two data frame are included in the merged data set; the default is FALSE.

...

Not used.

Author

John Fox

Details

This function merges two data frames by combining their rows.

See Also

For column merges and more complex merges, see merge.

Examples

Run this code
data(Duncan)
D1 <- Duncan[1:20,]
D2 <- Duncan[21:45,]
D <- mergeRows(D1, D2)
print(D)
dim(D)

Run the code above in your browser using DataLab