The function takes an object of class "boot" and creates an array of density estimates for the bootstrap distributions of the parameters.
Creates an array of adaptive kernal density plots, using densityPlot in the car package, showing the bootstrap distribution, point estimate ,and (optionally) confidence limits for each parameter.