Learn R Programming

RcmdrMisc (version 2.10.2)

rcorr.adjust: Compute Pearson or Spearman Correlations with p-Values

Description

Compute Pearson or Spearman Correlations with p-Values

Usage

rcorr.adjust(
  x,
  type = c("pearson", "spearman"),
  use = c("complete.obs", "pairwise.complete.obs")
)

# S3 method for rcorr.adjust print(x, ...)

Value

Returns an object of class "rcorr.adjust", which is normally just printed.

Arguments

x

a numeric matrix or data frame, or an object of class "rcorr.adjust" to be printed.

type

"pearson" or "spearman", depending upon the type of correlations desired; the default is "pearson".

use

how to handle missing data: "complete.obs", the default, use only complete cases; "pairwise.complete.obs", use all cases with valid data for each pair.

...

not used.

Author

John Fox, adapting code from Robert A. Muenchen.

Details

This function uses the rcorr function in the Hmisc package to compute matrices of Pearson or Spearman correlations along with the pairwise p-values among the correlations. The p-values are corrected for multiple inference using Holm's method (see p.adjust). Observations are filtered for missing data, and only complete observations are used.

See Also

Examples

Run this code
data(Mroz)
print(rcorr.adjust(Mroz[,c("k5", "k618", "age", "lwg", "inc")]))
print(rcorr.adjust(Mroz[,c("k5", "k618", "age", "lwg", "inc")], type="spearman"))

Run the code above in your browser using DataLab