readSPSS reads an SPSS data set, stored in a file of type .sav or .por, into an R data frame; it provides
a front end to the read_spss function in the haven package and the read.spss function in the foreign package.
readSPSS(file, rownames=FALSE, stringsAsFactors=default.stringsAsFactors(),
tolower=TRUE, use.haven=!por)path to an SPSS .sav or .por file.
if TRUE (the default is FALSE), the first column in the
data set contains row names, which should be unique.
if TRUE then columns containing character data are converted to
factors and factors are created from SPSS value labels;
the default is taken from default.stringsAsFactors().
change variable names to lowercase, default TRUE.
a data frame