Read a Stata Data Set
readStata(
file,
rownames = FALSE,
stringsAsFactors = FALSE,
convert.dates = TRUE
)a data frame.
path to a Stata .dta file.
if TRUE (the default is FALSE), the first column in the data set contains row names, which should be unique.
if TRUE (the default is FALSE) then columns containing character data are converted to factors and factors are created from Stata value labels.
if TRUE (the default) then Stata dates are converted to R dates.
John Fox
readStata reads a Stata data set, stored in a file of type .dta, into an R data frame; it provides a front end to the read.dta13 function in the readstata13 package.
read.dta13