Read an Excel File
readXL(
file,
rownames = FALSE,
header = TRUE,
na = "",
sheet = 1,
stringsAsFactors = FALSE
)a data frame.
name of an Excel file including its path.
if TRUE (the default is FALSE), the first column in the spreadsheet contains row names (which must be unique---i.e., no duplicates).
if TRUE (the default), the first row in the spreadsheet contains column (variable) names.
character string denoting missing data; the default is the empty string, "".
number of the spreadsheet in the file containing the data to be read; the default is 1.
if TRUE (the default is FALSE) then columns containing character data are converted to factors.
John Fox
readXL reads an Excel file, either of type .xls or .xlsx into an R data frame; it provides a front end to the read_excel function in the readxl package.
excel_sheets is re-exported from the readxl package and reports the names of spreadsheets in an Excel file.