summarySandwich: Linear Model Summary with Sandwich Standard Errors
Description
Linear Model Summary with Sandwich Standard Errors
Usage
summarySandwich(model, ...)
# S3 method for lm
summarySandwich(model, type = c("hc3", "hc0", "hc1", "hc2", "hc4", "hac"), ...)
Value
an object of class "summary.lm", with sandwich standard errors substituted for the usual OLS standard errors; the omnibus F-test is similarly adjusted.
Arguments
model
a linear-model object.
...
arguments to be passed to hccm or vcovHAC.
type
type of sandwich standard errors to be computed; see hccm in the car package, and vcovHAC in the sandwich package, for details.
Author
John Fox
Details
summarySandwich creates a summary of a "lm" object similar to the standard one, with sandwich estimates of the coefficient standard errors in the place of the usual OLS standard errors, also modifying as a consequence the reported t-tests and p-values for the coefficients.
Standard errors may be computed from a heteroscedasticity-consistent ("HC") covariance matrix for the coefficients (of several varieties), or from a heteroscedasticity-and-autocorrelation-consistent ("HAC") covariance matrix.