powered by
The Gumbel Distribution
dgumbel(x, location = 0, scale = 1)pgumbel(q, location = 0, scale = 1, lower.tail = TRUE)qgumbel(p, location = 0, scale = 1, lower.tail = TRUE)rgumbel(n, location = 0, scale = 1)
pgumbel(q, location = 0, scale = 1, lower.tail = TRUE)
qgumbel(p, location = 0, scale = 1, lower.tail = TRUE)
rgumbel(n, location = 0, scale = 1)
vector of values of the variable.
location parameter (default 0); potentially a vector.
0
scale parameter (default 1); potentially a vector.
1
vector of quantiles.
logical; if TRUE (the default) probabilities and quantiles correspond to \(P(X \le x)\), if FALSE to \(P(X > x)\).
TRUE
FALSE
vector of probabilities.
number of observations. If length(n) > 1, the length is taken to be the number required.
length(n)
John Fox
Density, distribution function, quantile function and random generation for the Gumbel distribution with specified location and scale parameters.
location
scale
See https://en.wikipedia.org/wiki/Gumbel_distribution for details of the Gumbel distribution.
x <- 100 + 5*c(-Inf, -1, 0, 1, 2, 3, Inf, NA) dgumbel(x, 100, 5) pgumbel(x, 100, 5) p <- c(0, .25, .5, .75, 1, NA) qgumbel(p, 100, 5) summary(rgumbel(1e5, 100, 5))
Run the code above in your browser using DataLab