Learn R Programming

RcmdrMisc (version 2.10.2)

colPercents: Row, Column, and Total Percentage Tables

Description

Row, Column, and Total Percentage Tables

Usage

colPercents(tab, digits = 1)

rowPercents(tab, digits = 1)

totPercents(tab, digits = 1)

Value

Returns an array of the same size and shape as tab percentaged by rows or columns, plus rows or columns of totals and counts, or by the table total.

Arguments

tab

a matrix or higher-dimensional array of frequency counts.

digits

number of places to the right of the decimal place for percentages.

Author

John Fox

Details

Percentage a matrix or higher-dimensional array of frequency counts by rows, columns, or total frequency.

Examples

Run this code
data(Mroz) # from car package
cat("\n\n column percents:\n")
print(colPercents(xtabs(~ lfp + wc, data=Mroz)))
cat("\n\n row percents:\n")
print(rowPercents(xtabs(~ hc + lfp, data=Mroz)))
cat("\n\n total percents:\n")
print(totPercents(xtabs(~ hc + wc, data=Mroz)))
cat("\n\n three-way table, column percents:\n")
print(colPercents(xtabs(~ lfp + wc + hc, data=Mroz)))

Run the code above in your browser using DataLab