optionally a factor (or character or logical variable) by which to classify x.
scale
either "frequency" (the default) or "percent".
xlab
optional character string to label the horizontal axis.
ylab
optional character string to label the vertical axis.
main
optional main label for the plot (ignored if the by argument is specified).
xlim
two-element numeric vectors specifying the range of the x axes; if not specified, will be determined from the data.
ylim
two-element numeric vectors specifying the range of the y axes; if not specified, will be determined from the data; the lower limit of the y-axis should normally be 0 and a warning will be printed if it isn't.
Plot the distribution of a discrete numeric variable, optionally classified by a factor.
If the by argument is specified, then one plot is produced for each level of by; these are arranged vertically and all use the same scale for the horizontal and vertical axes.