powered by
Function to Merge Rows of Two Data Frames
mergeRows(X, Y, common.only = FALSE, ...)# S3 method for data.frame mergeRows(X, Y, common.only = FALSE, ...)
# S3 method for data.frame mergeRows(X, Y, common.only = FALSE, ...)
A data frame containing the rows from both input data frames.
First data frame.
Second data frame.
If TRUE, only variables (columns) common to the two data frame are included in the merged data set; the default is FALSE.
TRUE
FALSE
Not used.
John Fox
This function merges two data frames by combining their rows.
For column merges and more complex merges, see merge.
merge
data(Duncan) D1 <- Duncan[1:20,] D2 <- Duncan[21:45,] D <- mergeRows(D1, D2) print(D) dim(D)
Run the code above in your browser using DataLab