powered by
Partial Correlations
partial.cor(X, tests = FALSE, use = c("complete.obs", "pairwise.complete.obs"))# S3 method for partial.cor print(x, digits = max(3, getOption("digits") - 2), ...)
# S3 method for partial.cor print(x, digits = max(3, getOption("digits") - 2), ...)
Returns the matrix of partial correlations, optionally with adjusted and unadjusted p-values.
data matrix.
show two-sided p-value and p-value adjusted for multiple testing by Holm's method for each partial correlation.
observations to use to compute partial correlations, default is "complete.obs".
"complete.obs"
minimal number of _significant_ digits, see print.default.
print.default
arguments to pass down from the print method.
John Fox
Computes a matrix of partial correlations between each pair of variables controlling for the others.
cor
data(DavisThin, package="car") partial.cor(DavisThin) partial.cor(DavisThin, tests=TRUE)
Run the code above in your browser using DataLab