Read a SAS b7dat Data Set
readSAS(file, rownames = FALSE, stringsAsFactors = FALSE)a data frame.
path to a SAS b7dat file.
if TRUE (the default is FALSE), the first column in the data set contains row names (which must be unique---i.e., no duplicates).
if TRUE (the default is FALSE) then columns containing character data are converted to factors.
John Fox
readSAS reads a SAS ``b7dat'' data set, stored in a file of type .sas7bdat, into an R data frame; it provides a front end to the read_sas function in the haven package.